;;; bandali-ido.el --- bandali's Ido setup           -*- lexical-binding: t; -*-

;; Copyright (C) 2018-2020  Amin Bandali

;; Author: Amin Bandali <bandali@gnu.org>
;; Keywords: convenience, matching

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; My (currently unused) Ido setup.

;;; Code:

(use-package ido
  :demand
  :bind
  (:map ido-common-completion-map
        ([escape] . minibuffer-keyboard-quit)
        ("DEL"    . b/ido-backspace))
  :config
  (require 'delsel)
  (defun b/ido-backspace ()
    "Forward to `backward-delete-char'.  On error (read-only), quit."
    (interactive)
    (condition-case nil
        (backward-delete-char 1)
      (error
       (minibuffer-keyboard-quit))))
  (ido-mode 1)
  (ido-everywhere 1)
  :custom
  (ido-enable-flex-matching t)
  ;; (ido-enable-regexp t)
  ;; (ido-enable-prefix t)
  (ido-max-window-height 10)
  (ido-use-virtual-buffers t))

(use-package ido-vertical-mode
  :defer 0.3
  :config
  (ido-vertical-mode 1)
  :custom
  (ido-vertical-define-keys 'C-n-C-p-up-and-down)
  (ido-vertical-show-count t))

(use-package ido-completing-read+
  :defer 0.3
  :after ido
  :config
  (ido-ubiquitous-mode 1))

(use-package crm-custom
  :defer 0.3
  :after crm
  :config
  (crm-custom-mode 1))

(use-package ido-at-point
  :defer 0.3
  :config
  (ido-at-point-mode 1))

(provide 'bandali-ido)
;;; bandali-ido.el ends here
